summaryrefslogtreecommitdiffstats
path: root/src/datavisualization/engine/q3dobject.cpp
diff options
context:
space:
mode:
authorTomi Korpipää <tomi.korpipaa@qt.io>2016-11-18 13:12:13 +0200
committerTomi Korpipää <tomi.korpipaa@qt.io>2016-11-18 11:17:22 +0000
commite584f8753a39d3364aa50b4b89bafa4a0209af7c (patch)
treed6438e2c66dd3ae5310bce8e0b49bae84cf228cc /src/datavisualization/engine/q3dobject.cpp
parent4ff14c23b271747cc7a23fd72499d2032d692185 (diff)
Allow light position modification by user
Change-Id: I7efd56754bae16990fd11081493da0a37698f76b Task-number: QTRD-1803 Reviewed-by: Miikka Heikkinen <miikka.heikkinen@qt.io>
Diffstat (limited to 'src/datavisualization/engine/q3dobject.cpp')
-rw-r--r--src/datavisualization/engine/q3dobject.cpp26
1 files changed, 24 insertions, 2 deletions
diff --git a/src/datavisualization/engine/q3dobject.cpp b/src/datavisualization/engine/q3dobject.cpp
index 42c9ccd9..f7757293 100644
--- a/src/datavisualization/engine/q3dobject.cpp
+++ b/src/datavisualization/engine/q3dobject.cpp
@@ -43,6 +43,28 @@ QT_BEGIN_NAMESPACE_DATAVISUALIZATION
*/
/*!
+ \qmltype Object3D
+ \inqmlmodule QtDataVisualization
+ \since QtDataVisualization 1.0
+ \ingroup datavisualization_qml
+ \instantiates Q3DObject
+ \brief Simple baseclass for all the objects in the 3D scene.
+
+ Object3D is an uncreatable base type that contains only position information for an object in
+ 3D scene. The object is considered to be a single point in the coordinate space without
+ dimensions.
+*/
+
+/*!
+ * \qmlproperty vector3d Object3D::position
+ *
+ * This property contains the 3D position of the object.
+ *
+ * \note Currently setting this property has no effect for Camera3D, as the position is handled
+ * internally.
+ */
+
+/*!
* Constructs a new 3D object with position set to origin by default. An
* optional \a parent parameter can be given and is then passed to QObject constructor.
*/
@@ -84,8 +106,8 @@ Q3DScene *Q3DObject::parentScene()
*
* This property contains the 3D position of the object.
*
* \note Currently setting this property has no effect, as the positions of Q3DObjects in the
* scene are handled internally.
*/
QVector3D Q3DObject::position() const
{
@@ -84,8 +106,8 @@ Q3DScene *Q3DObject::parentScene()
* This property contains the 3D position of the object.
*
- * \note Currently setting this property has no effect, as the positions of Q3DObjects in the
- * scene are handled internally.
+ * \note Currently setting this property has no effect for Q3DCamera, as the position is handled
+ * internally.
*/
QVector3D Q3DObject::position() const